==> unixODBC-1.8.8.tar.gz: unixODBC-1.8.8/include/sqp.h <==
#ifndef _SQP_H
#define _SQP_H

#include <lst.h>

/***********************
 * SQL - OUR SUPPORTED LANGUAGE COMPONENTS IN THEIR PARSED FORM
 ***********************/
typedef struct tSQPTABLE
{
	char *pszOwner;
	char *pszTable;

} SQPTABLE, *HSQPTABLE;

typedef struct tSQPCOLUMN
{
	char 	*pszTable;
	char 	*pszColumn;

	int		nColumn;			/* index into row data for col value	*/

} SQPCOLUMN, *HSQPCOLUMN;

typedef struct tSQPCOMPARISON
{
	char *pszLValue;			/* must be a column name 				*/
	char *pszOperator;			/* > < >= <= = 							*/
	char *pszRValue;			/* must be a string (quotes removed)	*/

	int  nLColumn;				/* index into row data for col value	*/

} SQPCOMPARISON, *HSQPCOMPARISON;

typedef struct tSQPASSIGNMENT
{
	char *pszColumn;
	char *pszValue;			

	int  nColumn;				/* index into row data for col value	*/

} SQPASSIGNMENT, *HSQPASSIGNMENT;

typedef struct tSQPSELECT
{
	HLST		hColumns;
	char 		*pszTable;
	HLST		hWhere;

} SQPSELECT, *HSQPSELECT;

typedef struct tSQPDELETE
{
	char 		*pszTable;
	HLST		hWhere;
	char		*pszCursor;

} SQPDELETE, *HSQPDELETE;

typedef struct tSQPINSERT
{
	char 		*pszTable;
	HLST		hValues;

} SQPINSERT, *HSQPINSERT;

typedef struct tSQPUPDATE
{
	char 		*pszTable;
	HLST		hAssignments;
	HLST		hWhere;
	char		*pszCursor;

} SQPUPDATE, *HSQPUPDATE;


enum sqpStatements
{
	sqpselect,
	sqpdelete,
	sqpinsert,
	sqpupdate
};

/***********************
 * GLOBALS (yuck... gotta get rid of them):
 *
 * TEMPS USED WHEN LEX/YACC DO THEIR THING
 ***********************/
char		g_szError[1024];

HSQPUPDATE	g_pUpdate;
HSQPSELECT	g_pSelect;
HSQPINSERT	g_pInsert;
HSQPDELETE	g_pDelete;

char		*g_pszTable;
HLST		g_hColumns;
HLST		g_hComparisons;
HLST		g_hValues;
HLST		g_hAssignments;
char		*g_pszCursor;

char		*g_pszSQLCursor;		/* yyparse position init to start of SQL string before yyparse	*/
char		*g_pszSQLLimit;			/* ptr to NULL terminator of SQL string (yyparse stops here)	*/
int 		g_nLineNo;


/*********************************************************************************************
 * INTERFACE
 *********************************************************************************************/
#if defined(__cplusplus)
         extern  "C" {
#endif

int		my_yyinput(char *buf, int max_size);
void	yyerror( char *s );

void sqpClearGlobals();
void sqpFreeAssignment( void *pData );
void sqpFreeColumn( void *pData );
void sqpFreeComparison( void *pData );
void sqpFreeDelete( void *pData );
void sqpFreeGlobals();
void sqpFreeInsert( void *pData );
int  sqpFreeSQL( void *p, int nType );
void sqpFreeSelect( void *pData );
void sqpFreeUpdate( void *pData );
void sqpStoreAssignment( char *pszColumn, char *pszValue );
void sqpStoreColumn( char *pszColumn );
void sqpStoreComparison( char *pszLValue, char *pszOperator, char *pszRValue );
void sqpStoreDelete();
void sqpStoreInsert();
void sqpStorePositioned( char *pszCursor );
void sqpStoreSelect();
void sqpStoreTable( char *pszTable );
void sqpStoreUpdate();
void sqpStoreValue( char *pszValue );


#if defined(__cplusplus)
         }
#endif


#endif

==> unixODBC-1.8.13.tar.gz: unixODBC-1.8.13/include/sqp.h <==
#ifndef _SQP_H
#define _SQP_H

#include <lst.h>

/***********************
 * SQL - OUR SUPPORTED LANGUAGE COMPONENTS IN THEIR PARSED FORM
 ***********************/
typedef struct tSQPTABLE
{
	char *pszOwner;
	char *pszTable;

} SQPTABLE, *HSQPTABLE;

typedef struct tSQPCOLUMN
{
	char 	*pszTable;
	char 	*pszColumn;

	int		nColumn;			/* index into row data for col value	*/

} SQPCOLUMN, *HSQPCOLUMN;

typedef struct tSQPCOMPARISON
{
	char *pszLValue;			/* must be a column name 				*/
	char *pszOperator;			/* > < >= <= = 							*/
	char *pszRValue;			/* must be a string (quotes removed)	*/

	int  nLColumn;				/* index into row data for col value	*/

} SQPCOMPARISON, *HSQPCOMPARISON;

typedef struct tSQPASSIGNMENT
{
	char *pszColumn;
	char *pszValue;			

	int  nColumn;				/* index into row data for col value	*/

} SQPASSIGNMENT, *HSQPASSIGNMENT;

typedef struct tSQPSELECT
{
	HLST		hColumns;
	char 		*pszTable;
	HLST		hWhere;

} SQPSELECT, *HSQPSELECT;

typedef struct tSQPDELETE
{
	char 		*pszTable;
	HLST		hWhere;
	char		*pszCursor;

} SQPDELETE, *HSQPDELETE;

typedef struct tSQPINSERT
{
	char 		*pszTable;
	HLST		hValues;

} SQPINSERT, *HSQPINSERT;

typedef struct tSQPUPDATE
{
	char 		*pszTable;
	HLST		hAssignments;
	HLST		hWhere;
	char		*pszCursor;

} SQPUPDATE, *HSQPUPDATE;


enum sqpStatements
{
	sqpselect,
	sqpdelete,
	sqpinsert,
	sqpupdate
};

/***********************
 * GLOBALS (yuck... gotta get rid of them):
 *
 * TEMPS USED WHEN LEX/YACC DO THEIR THING
 ***********************/
extern char		g_szError[1024];

extern HSQPUPDATE	g_pUpdate;
extern HSQPSELECT	g_pSelect;
extern HSQPINSERT	g_pInsert;
extern HSQPDELETE	g_pDelete;

extern char		*g_pszTable;
extern HLST		g_hColumns;
extern HLST		g_hComparisons;
extern HLST		g_hValues;
extern HLST		g_hAssignments;
extern char		*g_pszCursor;

extern char		*g_pszSQLCursor;		/* yyparse position init to start of SQL string before yyparse	*/
extern char		*g_pszSQLLimit;			/* ptr to NULL terminator of SQL string (yyparse stops here)	*/
extern int 		g_nLineNo;


/*********************************************************************************************
 * INTERFACE
 *********************************************************************************************/
#if defined(__cplusplus)
         extern  "C" {
#endif

int		my_yyinput(char *buf, int max_size);
void	yyerror( char *s );

void sqpClearGlobals();
void sqpFreeAssignment( void *pData );
void sqpFreeColumn( void *pData );
void sqpFreeComparison( void *pData );
void sqpFreeDelete( void *pData );
void sqpFreeGlobals();
void sqpFreeInsert( void *pData );
int  sqpFreeSQL( void *p, int nType );
void sqpFreeSelect( void *pData );
void sqpFreeUpdate( void *pData );
void sqpStoreAssignment( char *pszColumn, char *pszValue );
void sqpStoreColumn( char *pszColumn );
void sqpStoreComparison( char *pszLValue, char *pszOperator, char *pszRValue );
void sqpStoreDelete();
void sqpStoreInsert();
void sqpStorePositioned( char *pszCursor );
void sqpStoreSelect();
void sqpStoreTable( char *pszTable );
void sqpStoreUpdate();
void sqpStoreValue( char *pszValue );


#if defined(__cplusplus)
         }
#endif


#endif
